==> angular-form-components-0.0.1.tgz: package/src/select-with-input/select-with-input.component.ts <==
/**
 * desc：select-with-input
 * how to use: <select-with-input [(ngModel)]='your_prop' [options]='your_options' [disabled]='your_condition' ></select-with-input>
 */

import { Component, Input, Output, EventEmitter } from '@angular/core';
import {customInputAccessorm} from '../custom-input';

interface IOption{
    id: string;
    text: string;
}

@Component({
    selector: 'select-with-input',
    templateUrl: './select-with-input.component.html',
    providers: [customInputAccessor(SelectWithInputComponent)]
})
// ControlValueAccessor: A bridge between a control and a native element.
export class SelectWithInputComponent {
    @Input() options: IOption[] = []; // object: {id, text}
    @Input() disabled: boolean = false;
    @Output() select = new EventEmitter<any>();

    isOpen: boolean = false;

    private model: any = {}; // inner value
    private onChange: (_: any) => void;
    private onTouched: () => void;

    handleSelect(option: IOption){
        this.model = option.text;
        this.onChange(this.model);
    }

    isSelected(option: IOption){
        return this.options.findIndex(op => op.text === this.model) > -1;
    }

    // Set touched on blur
    onBlur() {
        this.onTouched();
    }

    // Write a new value to the element.
    writeValue(value: string): void {
        if (value && value.length) {
            this.model = value;
        }
    }

    // Set the function to be called when the control receives a change event.
    registerOnChange(fn: (_: any) => {}): void {
        this.onChange = fn;
    }

    // registerOnTouched(fn: any) : void
    registerOnTouched(fn: () => {}): void {
        this.onTouched = fn;
    }
}

==> angular-form-components-0.0.2.tgz: package/src/select-with-input/select-with-input.component.ts <==
/**
 * desc：select-with-input
 * how to use: <select-with-input [(ngModel)]='your_prop' [options]='your_options' [disabled]='your_condition' ></select-with-input>gi
 */

import { Component, Input, Output, EventEmitter } from '@angular/core';
import {customInputAccessor} from '../custom-input';

interface IOption{
    id: string;
    text: string;
}

@Component({
    selector: 'select-with-input',
    templateUrl: './select-with-input.component.html',
    styleUrls: ['./select-with-input.style.css'],
    providers: [customInputAccessor(SelectWithInputComponent)]
})
// ControlValueAccessor: A bridge between a control and a native element.
export class SelectWithInputComponent {
    @Input() options: IOption[] = []; // object: {id, text}
    @Input() disabled: boolean = false;
    @Output() select = new EventEmitter<any>();

    isOpen: boolean = false;

    private model: string = ''; // inner value
    private onChange: (_: any) => void;
    private onTouched: () => void;

    handleSelect(option: IOption){
        this.model = option.text;
        this.onChange(this.model);
        this.isOpen = false;
    }

    isSelected(option: IOption){
        return option.text === this.model;
    }

    // Set touched on blur
    onBlur() {
        this.onTouched();
    }

    // Write a new value to the element.
    writeValue(value: string): void {
        if (value) {
            this.model = value;
        }
    }

    // Set the function to be called when the control receives a change event.
    registerOnChange(fn: (_: any) => {}): void {
        this.onChange = fn;
    }

    // registerOnTouched(fn: any) : void
    registerOnTouched(fn: () => {}): void {
        this.onTouched = fn;
    }
}
